#!/usr/bin/perl
use strict;
use warnings "all";

if (!defined($ARGV[0]) || $ARGV[0] eq "-h" || $ARGV[0] =~ /^-?-help/) {
	print STDERR "proteinortho5_singletons.pl FASTA1 FASTA2 FASTAN <PROTEINORTHO_OUTFILE >SINGLETON_GENES\n";
	print STDERR "Reads Proteinortho outfile and its source fasta files to determin entries which occure once only\n\n";
	exit;
}

my %present; # Genes present in the matrix

### Parse matrix, store present genes
while (<STDIN>) {
	if ($_ =~ /^#/ || length($_) < 4) {next;}
	chomp;
	my @row = split(/\s|,/,$_);
	for (my $i = 3; $i < scalar(@row); $i++) {
		$present{$row[$i]} = 1;
	}
}

### For each fasta file, parse gene-IDs
foreach my $file (@ARGV) {
	print "\# $file\n";
	open(FILE,"<$file") || die("Error, could not open file $file: $!");
	while(<FILE>) {
		if ($_ =~ /^>([^\s]+)/) {
			my $id = $1;
			if (exists($present{$id})) {next;}
			print "$id\n";
		}
	}
	close(FILE);
}
